@@ -8,8 +8,6 @@ PKG_CONFIG_ID = "gtk+-2.0"
 TOPDIR = File.expand_path(File.dirname(__FILE__) + '/..')
 MKMF_GNOME2_DIR = TOPDIR + '/glib/src/lib'
 SRCDIR = TOPDIR + '/gtk/src'
-SRCDIR20 = TOPDIR + '/gtk/src20'
-SRCDIR22 = TOPDIR + '/gtk/src22'
 
 $LOAD_PATH.unshift MKMF_GNOME2_DIR
 
@@ -54,6 +52,13 @@ if target=="x11"
   have_func("XGetErrorText")
 end
 
+PKGConfig.have_package('gtk+-unix-print-2.0')
+
+have_func('gtk_print_unix_dialog_get_type')
+have_func('gtk_print_job_get_type')
+have_func('gtk_printer_get_type')
+have_func('gtk_page_setup_unix_get_type')
+
 PKGConfig.have_package('cairo')
 if have_header('rb_cairo.h')
   if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
@@ -79,19 +84,12 @@ add_distcleanfile("rbgtkinits.c")
 create_makefile_at_srcdir(PACKAGE_NAME, SRCDIR, "-DRUBY_GTK2_COMPILATION") {
   File.delete("rbgtkinits.c") if FileTest.exist?("rbgtkinits.c")
   File.delete("rbgtkinits.c") if FileTest.exist?("rbgtkinits.c")
-  system("ruby #{SRCDIR}/makeinits.rb #{SRCDIR}/*.c > rbgtkinits.c") or raise "failed to make GTK inits"
-  system("ruby #{SRCDIR}/makekeysyms.rb #{gdkincl}/gdkkeysyms.h > rbgdkkeysyms.h") or raise "failed to make GDK Keysyms"
+  system("#{$ruby} #{SRCDIR}/makeinits.rb #{SRCDIR}/*.c > rbgtkinits.c") or raise "failed to make GTK inits"
+  system("#{$ruby} #{SRCDIR}/makekeysyms.rb #{gdkincl}/gdkkeysyms.h > rbgdkkeysyms.h") or raise "failed to make GDK Keysyms"
 }
 
 $defs.delete("-DRUBY_GTK2_COMPILATION")
 
 add_depend_package("gtk2", "gtk/src", TOPDIR)
 
-create_makefile_at_srcdir("gtk20", SRCDIR20) {
-  $objs = ["rbgtk20.o"]
-}
-create_makefile_at_srcdir("gtk22", SRCDIR22) {
-  $objs = ["rbgtk22.o"]
-}
-
-create_top_makefile(["src", "src20", "src22"])
+create_top_makefile(["src"])
